1.0.0 API documentation: GLM_EXT_vector_int2_sized

| 1.0.0 API documentation

Typedefs
GLM_EXT_vector_int2_sized
Stable extensions

## Typedefs
typedef vec< 2, int16, defaultp > | i16vec2
| 16 bit signed integer vector of 2 components type. More...
typedef vec< 2, int32, defaultp > | i32vec2
| 32 bit signed integer vector of 2 components type. More...
typedef vec< 2, int64, defaultp > | i64vec2
| 64 bit signed integer vector of 2 components type. More...
typedef vec< 2, int8, defaultp > | i8vec2
| 8 bit signed integer vector of 2 components type. More...

## Detailed Description

Exposes sized signed integer vector of 2 components type.

Include <glm/ext/vector_int2_sized.hpp> to use the features of this extension.

See also
  GLM_EXT_scalar_int_sized
  GLM_EXT_vector_uint2_sized

## Typedef Documentation

## ◆ i16vec2

typedef vec< 2, i16, defaultp > i16vec2

16 bit signed integer vector of 2 components type.

See also
  GLM_EXT_vector_int2_sized

Definition at line 36 of file vector_int2_sized.hpp.

## ◆ i32vec2

typedef vec< 2, i32, defaultp > i32vec2

32 bit signed integer vector of 2 components type.

See also
  GLM_EXT_vector_int2_sized

Definition at line 41 of file vector_int2_sized.hpp.

## ◆ i64vec2

typedef vec< 2, i64, defaultp > i64vec2

64 bit signed integer vector of 2 components type.

See also
  GLM_EXT_vector_int2_sized

Definition at line 46 of file vector_int2_sized.hpp.

## ◆ i8vec2

typedef vec< 2, i8, defaultp > i8vec2

8 bit signed integer vector of 2 components type.

See also
  GLM_EXT_vector_int2_sized

Definition at line 31 of file vector_int2_sized.hpp.